@@ -35,7 +35,7 @@
 #endif
 #endif
 
-#if BUFSIZ < 1024
+#if BUFSIZ <= 1024
 #define DEFAULTALLOC 8192
 #else
 #define	DEFAULTALLOC BUFSIZ
