@@ -13,7 +13,7 @@ static PyObject *mode, *match_finder, *format;
 static PyObject *
 libLZMAOptions_repr(libLZMAOptionsObject *obj)
 {
-    return PyString_FromFormat("%s singleton for accessing descriptors", obj->ob_type->tp_name);
+	return PyString_FromFormat("%s singleton for accessing descriptors", obj->ob_type->tp_name);
 }
 
 static void
@@ -31,7 +31,7 @@ libLZMAOptions_dealloc(libLZMAOptionsObject* self)
 	Py_XDECREF(self->match_finder_dict);
 	Py_XDECREF(self->match_finder);
 	Py_XDECREF(self->match_finder_cycles);
-    self->ob_type->tp_free((PyObject*)self);
+	self->ob_type->tp_free((PyObject*)self);
 }
 
 PyObject *
@@ -56,7 +56,7 @@ bool init_lzma_options(const char *funcName, PyObject *kwargs, lzma_options_lzma
 	const char *argtypes = "|iiiiiiOO:";
 	PyObject *args;
 	char argstring[strlen(argtypes)+strlen(funcName)+2];
-    static char *kwlist[] = {"dictionary_size",
+    	static char *kwlist[] = {"dictionary_size",
 		"literal_context_bits", "literal_pos_bits", "pos_bits", "fast_bytes",
 		"match_finder_cycles", "mode", "match_finder", 0};
 	PyObject *mf_key = NULL, *mode_key = NULL;
@@ -97,14 +97,19 @@ bool init_lzma_options(const char *funcName, PyObject *kwargs, lzma_options_lzma
 				&options->match_finder_cycles, &mode_key, &mf_key))
 		return false;
 	Py_XDECREF(args);
-	CHECK_RANGE(options->dictionary_size, LZMA_DICTIONARY_SIZE_MIN, LZMA_DICTIONARY_SIZE_MAX, "dictionary_size must be between %d and %d, got %d");
-    CHECK_RANGE(options->literal_context_bits, LZMA_LITERAL_CONTEXT_BITS_MIN, LZMA_LITERAL_CONTEXT_BITS_MAX, "literal_context_bits must be between %d and %d, got %d");
-    CHECK_RANGE(options->literal_pos_bits, LZMA_POS_BITS_MIN, LZMA_POS_BITS_MAX, "literal_pos_bits must be between %d and %d, got %d");
-    CHECK_RANGE(options->pos_bits, LZMA_POS_BITS_MIN, LZMA_POS_BITS_MAX, "pos_bits must be between %d and %d, got %d");
-    CHECK_RANGE(options->fast_bytes, LZMA_FAST_BYTES_MIN, LZMA_FAST_BYTES_MAX, "fast_bytes must be between %d and %d, got %d");
+	CHECK_RANGE(options->dictionary_size, LZMA_DICTIONARY_SIZE_MIN,
+			LZMA_DICTIONARY_SIZE_MAX, "dictionary_size must be between %d and %d, got %d");
+    	CHECK_RANGE(options->literal_context_bits, LZMA_LITERAL_CONTEXT_BITS_MIN,
+			LZMA_LITERAL_CONTEXT_BITS_MAX, "literal_context_bits must be between %d and %d, got %d");
+    	CHECK_RANGE(options->literal_pos_bits, LZMA_POS_BITS_MIN, LZMA_POS_BITS_MAX,
+		       	"literal_pos_bits must be between %d and %d, got %d");
+    	CHECK_RANGE(options->pos_bits, LZMA_POS_BITS_MIN, LZMA_POS_BITS_MAX,
+		       	"pos_bits must be between %d and %d, got %d");
+    	CHECK_RANGE(options->fast_bytes, LZMA_FAST_BYTES_MIN, LZMA_FAST_BYTES_MAX,
+		       	"fast_bytes must be between %d and %d, got %d");
 	if((int)options->match_finder_cycles < 0){
-			PyErr_Format(PyExc_ValueError, "match_finder_cycles must be >= 0");
-			return false;
+		PyErr_Format(PyExc_ValueError, "match_finder_cycles must be >= 0");
+		return false;
 	}
 
 	/* FIXME: This could be done a lot simpler.. */
@@ -113,20 +118,20 @@ bool init_lzma_options(const char *funcName, PyObject *kwargs, lzma_options_lzma
 		if(PyInt_Check(mode_key))
 			options->mode = PyInt_AsLong(mode_key);
 		else
-		if(PyString_Check(mode_key) && PyDict_Contains(mode, mode_key))
+			if(PyString_Check(mode_key) && PyDict_Contains(mode, mode_key))
 				options->mode = PyInt_AsLong(PyDict_GetItem(mode, mode_key));
-		else if(PyString_Check(mode_key)){
-			PyObject *key, *value;
-			Py_ssize_t pos = 0;
-			
-			while (PyDict_Next(mode, &pos, &key, &value)) {
-				if(PyObject_RichCompareBool(mode_key,value,Py_EQ)){
-					options->mode = PyInt_AsLong(key);
-					break;
+			else if(PyString_Check(mode_key)){
+				PyObject *key, *value;
+				Py_ssize_t pos = 0;
+				
+				while (PyDict_Next(mode, &pos, &key, &value)) {
+					if(PyObject_RichCompareBool(mode_key,value,Py_EQ)){
+						options->mode = PyInt_AsLong(key);
+						break;
+					}
 				}
 			}
 		}
-	}
 	Py_XDECREF(mode_key);
 	switch(options->mode){
 		case(LZMA_MODE_FAST):
@@ -145,9 +150,8 @@ bool init_lzma_options(const char *funcName, PyObject *kwargs, lzma_options_lzma
 		options->match_finder = LZMA_MF_INVALID;
 		if(PyInt_Check(mf_key))
 			options->match_finder = PyInt_AsLong(mf_key);
-		else
-		if(PyString_Check(mf_key) && PyDict_Contains(match_finder, mf_key))
-				options->match_finder = PyInt_AsLong(PyDict_GetItem(match_finder, mf_key));
+		else if(PyString_Check(mf_key) && PyDict_Contains(match_finder, mf_key))
+			options->match_finder = PyInt_AsLong(PyDict_GetItem(match_finder, mf_key));
 		else if(PyString_Check(mf_key)){
 			PyObject *key, *value;
 			Py_ssize_t pos = 0;
@@ -189,26 +193,39 @@ libLZMAOptions_alloc(PyTypeObject *type, Py_ssize_t nitems)
 	self->format = PyTuple_Pack(1, PyString_FromString("alone"));
 	format = self->format;
 	self->eopm = PyTuple_Pack(2, Py_False, Py_True);
-	self->level = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_BEST_SPEED), PyInt_FromLong((ulong)LZMA_BEST_COMPRESSION));
-	self->dictionary_size = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_DICTIONARY_SIZE_MIN), PyInt_FromLong((ulong)LZMA_DICTIONARY_SIZE_MAX));
-	self->literal_context_bits = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_LITERAL_CONTEXT_BITS_MIN), PyInt_FromLong((ulong)LZMA_LITERAL_CONTEXT_BITS_MAX));
-	self->literal_pos_bits = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_LITERAL_POS_BITS_MIN), PyInt_FromLong((ulong)LZMA_LITERAL_POS_BITS_MAX));
-	self->pos_bits = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_POS_BITS_MIN), PyInt_FromLong((ulong)LZMA_POS_BITS_MAX));
+	self->level = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_BEST_SPEED),
+			PyInt_FromLong((ulong)LZMA_BEST_COMPRESSION));
+	self->dictionary_size = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_DICTIONARY_SIZE_MIN),
+			PyInt_FromLong((ulong)LZMA_DICTIONARY_SIZE_MAX));
+	self->literal_context_bits = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_LITERAL_CONTEXT_BITS_MIN),
+			PyInt_FromLong((ulong)LZMA_LITERAL_CONTEXT_BITS_MAX));
+	self->literal_pos_bits = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_LITERAL_POS_BITS_MIN),
+			PyInt_FromLong((ulong)LZMA_LITERAL_POS_BITS_MAX));
+	self->pos_bits = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_POS_BITS_MIN),
+			PyInt_FromLong((ulong)LZMA_POS_BITS_MAX));
 	self->mode_dict = PyDict_New();
-	self->fast_bytes = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_FAST_BYTES_MIN), PyInt_FromLong((ulong)LZMA_FAST_BYTES_MAX));
+	self->fast_bytes = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_FAST_BYTES_MIN),
+		       	PyInt_FromLong((ulong)LZMA_FAST_BYTES_MAX));
 	self->match_finder_dict = PyDict_New();
 	self->match_finder_cycles = PyInt_FromLong(0);
 
-	PyDict_SetItem(self->mode_dict, PyInt_FromLong((ulong)LZMA_MODE_FAST), PyString_FromString("fast"));
-	PyDict_SetItem(self->mode_dict, PyInt_FromLong((ulong)LZMA_MODE_BEST), PyString_FromString("best"));
+	PyDict_SetItem(self->mode_dict, PyInt_FromLong((ulong)LZMA_MODE_FAST),
+			PyString_FromString("fast"));
+	PyDict_SetItem(self->mode_dict, PyInt_FromLong((ulong)LZMA_MODE_BEST),
+			PyString_FromString("best"));
 	mode = self->mode_dict;
 
 	self->mode = PyList_AsTuple(PyDict_Values(self->mode_dict));
-	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_HC3), PyString_FromString("hc3"));
-	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_HC4), PyString_FromString("hc4"));
-	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_BT2), PyString_FromString("bt2"));
-	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_BT3), PyString_FromString("bt3"));
-	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_BT4), PyString_FromString("bt4"));
+	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_HC3),
+			PyString_FromString("hc3"));
+	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_HC4),
+			PyString_FromString("hc4"));
+	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_BT2),
+			PyString_FromString("bt2"));
+	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_BT3),
+			PyString_FromString("bt3"));
+	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_BT4),
+			PyString_FromString("bt4"));
 	mf_list = PyDict_Values(self->match_finder_dict);
 	PyList_Sort(mf_list);
 	self->match_finder =  PyList_AsTuple(mf_list);
@@ -234,7 +251,8 @@ level\t lc\t lp\t dict\t\t pb\t mode\t mf\t fb\t mfc\n");
 	
 	{off_t i;
 	for(i = LZMA_BEST_COMPRESSION; i >= LZMA_BEST_SPEED; i--){
-		PyObject *settingsString = PyString_Format(levelopts, PyList_AsTuple(PyDict_Values(libLZMA_options_get(lzma_preset_lzma[i-1]))));
+		PyObject *settingsString = PyString_Format(levelopts,
+			       	PyList_AsTuple(PyDict_Values(libLZMA_options_get(lzma_preset_lzma[i-1]))));
 		PyObject *levelNum = PyString_Format(settingsString, PyInt_FromLong(i));
 		PyString_Concat(&levelString,levelNum);
 		Py_DECREF(settingsString);
@@ -326,52 +344,52 @@ libLZMAOptions_setattr(__attribute__((unused)) libLZMAOptionsObject *self, const
 }
 
 PyTypeObject libLZMAOptions_Type = {
-	0,										/*ob_refcnt*/
-	0,										/*ob_type*/
-	0,										/*ob_size*/
-	"liblzma.LZMAOptions",					/*tp_name*/
-	sizeof(libLZMAOptionsObject),			/*tp_basicsize*/
-	0,										/*tp_itemsize*/
-	(destructor)libLZMAOptions_dealloc,		/*tp_dealloc*/
-	0,										/*tp_print*/
-	0,										/*tp_getattr*/
+	0,					/*ob_refcnt*/
+	0,					/*ob_type*/
+	0,					/*ob_size*/
+	"liblzma.LZMAOptions",			/*tp_name*/
+	sizeof(libLZMAOptionsObject),		/*tp_basicsize*/
+	0,					/*tp_itemsize*/
+	(destructor)libLZMAOptions_dealloc,	/*tp_dealloc*/
+	0,					/*tp_print*/
+	0,					/*tp_getattr*/
 	(setattrfunc)libLZMAOptions_setattr,	/*tp_setattr*/
-	0,										/*tp_compare*/
-	(reprfunc)libLZMAOptions_repr,			/*tp_repr*/
-	0,										/*tp_as_number*/
-	0,										/*tp_as_sequence*/
-	0,										/*tp_as_mapping*/
-	0,										/*tp_hash*/
-	0,										/*tp_call*/
-	0,										/*tp_str*/
-	0,										/*tp_getattro*/
-	0,										/*tp_setattro*/
-	0,										/*tp_as_buffer*/
-	0,										/*tp_flags*/
-	libLZMAOptions__doc__,         			/*tp_doc*/
-	0,										/*tp_traverse*/
-	0,										/*tp_clear*/
-	0,										/*tp_richcompare*/
-	0,										/*tp_weaklistoffset*/
-	0,										/*tp_iter*/
-	0,										/*tp_iternext*/
-	0,										/*tp_methods*/
-	libLZMAOptions_members,					/*tp_members*/
-	0,										/*tp_getset*/
-	0,										/*tp_base*/
-	0,										/*tp_dict*/
-	0,										/*tp_descr_get*/
-	0,										/*tp_descr_set*/
-	0,										/*tp_dictoffset*/
-	0,										/*tp_init*/
-	libLZMAOptions_alloc,					/*tp_alloc*/
-	0,										/*tp_new*/
-	0,										/*tp_free*/
-	0,										/*tp_is_gc*/
-	0,										/*tp_bases*/
-	0,										/*tp_mro*/
-	0,										/*tp_cache*/
-	0,										/*tp_subclasses*/
-	0,										/*tp_weaklist*/
-	0										/*tp_del*/
+	0,					/*tp_compare*/
+	(reprfunc)libLZMAOptions_repr,		/*tp_repr*/
+	0,					/*tp_as_number*/
+	0,					/*tp_as_sequence*/
+	0,					/*tp_as_mapping*/
+	0,					/*tp_hash*/
+	0,					/*tp_call*/
+	0,					/*tp_str*/
+	0,					/*tp_getattro*/
+	0,					/*tp_setattro*/
+	0,					/*tp_as_buffer*/
+	0,					/*tp_flags*/
+	libLZMAOptions__doc__,         		/*tp_doc*/
+	0,					/*tp_traverse*/
+	0,					/*tp_clear*/
+	0,					/*tp_richcompare*/
+	0,					/*tp_weaklistoffset*/
+	0,					/*tp_iter*/
+	0,					/*tp_iternext*/
+	0,					/*tp_methods*/
+	libLZMAOptions_members,			/*tp_members*/
+	0,					/*tp_getset*/
+	0,					/*tp_base*/
+	0,					/*tp_dict*/
+	0,					/*tp_descr_get*/
+	0,					/*tp_descr_set*/
+	0,					/*tp_dictoffset*/
+	0,					/*tp_init*/
+	libLZMAOptions_alloc,			/*tp_alloc*/
+	0,					/*tp_new*/
+	0,					/*tp_free*/
+	0,					/*tp_is_gc*/
+	0,					/*tp_bases*/
+	0,					/*tp_mro*/
+	0,					/*tp_cache*/
+	0,					/*tp_subclasses*/
+	0,					/*tp_weaklist*/
+	0					/*tp_del*/
 };
